@@ -9,30 +9,30 @@ import (
 	"syscall"
 	"time"
 
-	"github.com/cloudskiff/driftctl/build"
-	"github.com/cloudskiff/driftctl/pkg/analyser"
-	"github.com/cloudskiff/driftctl/pkg/memstore"
-	"github.com/cloudskiff/driftctl/pkg/remote/common"
-	"github.com/cloudskiff/driftctl/pkg/telemetry"
-	"github.com/cloudskiff/driftctl/pkg/terraform/lock"
 	"github.com/fatih/color"
 	"github.com/mitchellh/go-homedir"
 	"github.com/pkg/errors"
 	"github.com/sirupsen/logrus"
+	"github.com/snyk/driftctl/build"
+	"github.com/snyk/driftctl/pkg/analyser"
+	"github.com/snyk/driftctl/pkg/memstore"
+	"github.com/snyk/driftctl/pkg/remote/common"
+	"github.com/snyk/driftctl/pkg/telemetry"
+	"github.com/snyk/driftctl/pkg/terraform/lock"
 	"github.com/spf13/cobra"
 
-	"github.com/cloudskiff/driftctl/pkg"
-	"github.com/cloudskiff/driftctl/pkg/alerter"
-	cmderrors "github.com/cloudskiff/driftctl/pkg/cmd/errors"
-	"github.com/cloudskiff/driftctl/pkg/cmd/scan/output"
-	"github.com/cloudskiff/driftctl/pkg/filter"
-	"github.com/cloudskiff/driftctl/pkg/iac/config"
-	"github.com/cloudskiff/driftctl/pkg/iac/supplier"
-	"github.com/cloudskiff/driftctl/pkg/iac/terraform/state/backend"
-	globaloutput "github.com/cloudskiff/driftctl/pkg/output"
-	"github.com/cloudskiff/driftctl/pkg/remote"
-	"github.com/cloudskiff/driftctl/pkg/resource"
-	"github.com/cloudskiff/driftctl/pkg/terraform"
+	"github.com/snyk/driftctl/pkg"
+	"github.com/snyk/driftctl/pkg/alerter"
+	cmderrors "github.com/snyk/driftctl/pkg/cmd/errors"
+	"github.com/snyk/driftctl/pkg/cmd/scan/output"
+	"github.com/snyk/driftctl/pkg/filter"
+	"github.com/snyk/driftctl/pkg/iac/config"
+	"github.com/snyk/driftctl/pkg/iac/supplier"
+	"github.com/snyk/driftctl/pkg/iac/terraform/state/backend"
+	globaloutput "github.com/snyk/driftctl/pkg/output"
+	"github.com/snyk/driftctl/pkg/remote"
+	"github.com/snyk/driftctl/pkg/resource"
+	"github.com/snyk/driftctl/pkg/terraform"
 )
 
 func NewScanCmd(opts *pkg.ScanOptions) *cobra.Command {
