@@ -4,19 +4,19 @@ import (
 	"reflect"
 	"testing"
 
-	"github.com/cloudskiff/driftctl/pkg"
-	"github.com/cloudskiff/driftctl/pkg/alerter"
-	"github.com/cloudskiff/driftctl/pkg/analyser"
-	"github.com/cloudskiff/driftctl/pkg/filter"
-	"github.com/cloudskiff/driftctl/pkg/memstore"
-	"github.com/cloudskiff/driftctl/pkg/output"
-	"github.com/cloudskiff/driftctl/pkg/resource"
-	"github.com/cloudskiff/driftctl/pkg/resource/aws"
-	"github.com/cloudskiff/driftctl/pkg/resource/github"
-	"github.com/cloudskiff/driftctl/pkg/terraform"
-	"github.com/cloudskiff/driftctl/test"
-	testresource "github.com/cloudskiff/driftctl/test/resource"
 	"github.com/r3labs/diff/v2"
+	"github.com/snyk/driftctl/pkg"
+	"github.com/snyk/driftctl/pkg/alerter"
+	"github.com/snyk/driftctl/pkg/analyser"
+	"github.com/snyk/driftctl/pkg/filter"
+	"github.com/snyk/driftctl/pkg/memstore"
+	"github.com/snyk/driftctl/pkg/output"
+	"github.com/snyk/driftctl/pkg/resource"
+	"github.com/snyk/driftctl/pkg/resource/aws"
+	"github.com/snyk/driftctl/pkg/resource/github"
+	"github.com/snyk/driftctl/pkg/terraform"
+	"github.com/snyk/driftctl/test"
+	testresource "github.com/snyk/driftctl/test/resource"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/mock"
 )
@@ -73,8 +73,10 @@ func runTest(t *testing.T, cases TestCases) {
 				schema, _ := repo.GetSchema(res.ResourceType())
 				res.Sch = schema
 			}
-			remoteSupplier := &resource.MockSupplier{}
-			remoteSupplier.On("Resources").Return(c.remoteResources, nil)
+
+			remoteSupplier := &resource.MockRemoteSupplier{}
+			remoteSupplier.On("EnumerateResources").Return(c.remoteResources, nil)
+			remoteSupplier.On("ReadResources", mock.IsType([]*resource.Resource{})).Return(c.remoteResources, nil)
 
 			var resourceFactory resource.ResourceFactory = terraform.NewTerraformResourceFactory(repo)
 
@@ -88,8 +90,8 @@ func runTest(t *testing.T, cases TestCases) {
 			}
 
 			scanProgress := &output.MockProgress{}
-			scanProgress.On("Start").Return().Once()
-			scanProgress.On("Stop").Return().Once()
+			scanProgress.On("Start").Return().Times(2)
+			scanProgress.On("Stop").Return().Times(2)
 
 			iacProgress := &output.MockProgress{}
 			iacProgress.On("Start").Return().Once()
