@@ -3,13 +3,13 @@ package remote
 import (
 	"context"
 
-	"github.com/cloudskiff/driftctl/pkg/alerter"
-	"github.com/cloudskiff/driftctl/pkg/filter"
-	"github.com/cloudskiff/driftctl/pkg/parallel"
-	"github.com/cloudskiff/driftctl/pkg/remote/common"
-	"github.com/cloudskiff/driftctl/pkg/resource"
 	"github.com/pkg/errors"
 	"github.com/sirupsen/logrus"
+	"github.com/snyk/driftctl/pkg/alerter"
+	"github.com/snyk/driftctl/pkg/filter"
+	"github.com/snyk/driftctl/pkg/parallel"
+	"github.com/snyk/driftctl/pkg/remote/common"
+	"github.com/snyk/driftctl/pkg/resource"
 )
 
 type ScannerOptions struct {
@@ -58,7 +58,7 @@ loop:
 	return results, runner.Err()
 }
 
-func (s *Scanner) scan() ([]*resource.Resource, error) {
+func (s *Scanner) EnumerateResources() ([]*resource.Resource, error) {
 	for _, enumerator := range s.remoteLibrary.Enumerators() {
 		if s.filter.IsTypeIgnored(enumerator.SupportedType()) {
 			logrus.WithFields(logrus.Fields{
@@ -89,16 +89,11 @@ func (s *Scanner) scan() ([]*resource.Resource, error) {
 		})
 	}
 
-	enumerationResult, err := s.retrieveRunnerResults(s.enumeratorRunner)
-	if err != nil {
-		return nil, err
-	}
+	return s.retrieveRunnerResults(s.enumeratorRunner)
+}
 
-	if !s.options.Deep {
-		return enumerationResult, nil
-	}
-
-	for _, res := range enumerationResult {
+func (s *Scanner) ReadResources(managedResources []*resource.Resource) ([]*resource.Resource, error) {
+	for _, res := range managedResources {
 		res := res
 		s.detailsFetcherRunner.Run(func() (interface{}, error) {
 			fetcher := s.remoteLibrary.GetDetailsFetcher(resource.ResourceType(res.ResourceType()))
@@ -121,7 +116,17 @@ func (s *Scanner) scan() ([]*resource.Resource, error) {
 }
 
 func (s *Scanner) Resources() ([]*resource.Resource, error) {
-	resources, err := s.scan()
+	resources, err := s.EnumerateResources()
+	if err != nil {
+		return nil, err
+	}
+
+	if !s.options.Deep {
+		return resources, nil
+	}
+
+	// Be aware that this call will read all resources, no matter they're managed or not
+	resources, err = s.ReadResources(resources)
 	if err != nil {
 		return nil, err
 	}
