@@ -139,7 +139,14 @@ var supportedTypes = map[string]ResourceTypeMeta{
 	}},
 	"aws_appautoscaling_policy":           {},
 	"aws_appautoscaling_scheduled_action": {},
-	"aws_apigatewayv2_api":                {},
+	"aws_apigatewayv2_api": {children: []ResourceType{
+		"aws_apigatewayv2_route",
+	}},
+	"aws_apigatewayv2_route":      {},
+	"aws_apigatewayv2_vpc_link":   {},
+	"aws_apigatewayv2_authorizer": {},
+	"aws_launch_template":         {},
+	"aws_launch_configuration":    {},
 
 	"github_branch_protection": {},
 	"github_membership":        {},
@@ -180,6 +187,7 @@ var supportedTypes = map[string]ResourceTypeMeta{
 	"google_compute_image":           {},
 	"google_compute_health_check":    {},
 	"google_compute_global_address":  {},
+	"google_compute_node_group":      {},
 	"google_cloud_run_service":       {},
 
 	"azurerm_storage_account":   {},
@@ -200,6 +208,7 @@ var supportedTypes = map[string]ResourceTypeMeta{
 	"azurerm_public_ip":                {},
 	"azurerm_network_security_group":   {},
 	"azurerm_lb":                       {},
+	"azurerm_lb_rule":                  {},
 	"azurerm_private_dns_zone":         {},
 	"azurerm_private_dns_a_record":     {},
 	"azurerm_private_dns_aaaa_record":  {},
